@@ -1,7 +1,9 @@
 # TODO add function to guess media type given extension
 
 import re, fractions, subprocess as sp
-from .path import get_ffmpeg
+
+from .path import where
+from .utils.error import FFmpegError
 
 # fmt:off
 __all__ = ["options", "filters", "codecs", "coders", "formats", "devices",
@@ -28,7 +30,13 @@ _cache = dict()
 
 
 def ffmpeg(gopts):
-    return sp.run([get_ffmpeg(), '-hide_banner', *gopts], stdout=sp.PIPE, encoding="utf-8").stdout
+
+    out = sp.run([where(), "-hide_banner", *gopts], stdout=sp.PIPE, encoding="utf-8")
+
+    if out.returncode or out.stdout.count("\n") == 1:
+        raise FFmpegError(out.stdout)
+
+    return out.stdout
 
 
 def _(cap):
@@ -47,7 +55,7 @@ def options(type=None, name_only=False, return_desc=False):
     """get FFmpeg command options
 
     :param type: specify option type to return, defaults to None
-    :type type: "per-file"|"video"|"audio"|"subtitle"|"general"|"global"|None, optional
+    :type type: "per-file"\|"video"\|"audio"\|"subtitle"\|"general"\|"global"\|None, optional
     :param name_only: True to only return option names, defaults to False
     :type name_only: bool, optional
     :param return_desc: True to also return option description, defaults to False
@@ -369,9 +377,11 @@ def formats():
     return _getFormats("formats", True)
 
 
-def devices():
+def devices(type=None):
     """get FFmpeg devices
 
+    :param type: specify source or sink type, defaults to None
+    :type type: 'source'|'sink', optional
     :return: list of devices
     :rtype: dict
 
@@ -387,7 +397,14 @@ def devices():
     can_mux           bool  True if support outputs of this format
     ================  ====  ===============================================
     """
-    return _getFormats("devices", True)
+    devs = _getFormats("devices", True)
+    if type:
+        try:
+            key = {"source": "can_demux", "sink": "can_mux"}[type]
+        except:
+            raise ValueError(f'type must be either "source" or "sink"')
+        return {k: v for k, v in devs.items() if v[key]}
+    return devs
 
 
 def muxers():
@@ -757,12 +774,6 @@ def decoder_info(name):
     return _getCodecInfo(name, False)
 
 
-_re_layouts = re.compile(
-    re.sub(r"([().])", r"\\\1", "|".join(layouts()["layouts"]))
-    + r"|\d+ channels \(.+?\)"
-)
-
-
 def _getCodecInfo(name, encoder):
     #   // according to fftools/comdutils.c show_help_codec()
     stdout, data = __("encoder" if encoder else "decoder", name)
@@ -789,6 +800,11 @@ def _getCodecInfo(name, encoder):
         m = re.match(r"(\d+)\/(\d+)", s)
         return fractions.Fraction(int(m[1]), int(m[2]))
 
+    _re_layouts = re.compile(
+        re.sub(r"([().])", r"\\\1", "|".join(layouts()["layouts"]))
+        + r"|\d+ channels \(.+?\)"
+    )
+
     data = {
         "name": m[1],
         "long_name": m[2],
